#!/bin/csh
#
# Validate the user, make sure there is an FXA_LOCAL_SITE defined and
# that it points to a built localization.
#
if ( $USER != fxa ) then
    echo "This script needs to be run with the fxa account"
    echo "ABORTING\!\!\!"
    exit
endif
if ( ! ( $?FXA_LOCAL_SITE ) ) then
    echo there is no value for FXA_LOCAL_SITE
    exit
endif
if ( "$FXA_LOCAL_SITE" == "" ) then
    echo there is no value for FXA_LOCAL_SITE
    exit
endif
if ( ! (  -d $FXA_LOCALIZATION_ROOT/$FXA_LOCAL_SITE ) ) then
    echo localization data set directory 
    echo $FXA_LOCALIZATION_ROOT/$FXA_LOCAL_SITE does not exist
    exit
endif
#
setenv LOG_PREF ${FXA_HOME}/data/logPrefTTY
echo 'all all all all = off' > $LOG_PREF
echo 'all all tty all = on' >> $LOG_PREF
if ( "$1" == "debug" ) then
    echo >& /dev/null
else if ( "$1" == "verbose" ) then
    echo 'all all tty debug = off' >> $LOG_PREF
else
    echo 'all all tty debug = off' >> $LOG_PREF
    echo 'all all tty verbose = off' >> $LOG_PREF
endif
echo 'tty filename = on' >> $LOG_PREF
echo 'tty lineno = on' >> $LOG_PREF
echo 'tty timestamp = on' >> $LOG_PREF
echo 'tty processName = on' >> $LOG_PREF
#
if ( "$1" == "none" ) then
    set routerLog = /dev/null
    set decodersLog = /dev/null
    set imgDecLog = /dev/null
else
    set routerLog = $FXA_HOME/logs/GridRouter.log
    set decodersLog = $FXA_HOME/logs/GribDecoders.log
    set imgDecLog = $FXA_HOME/logs/GribImgDecoder.log
endif
#
setenv FXA_DATA /scratch/local/data/fxa
mkdir -p $FXA_HOME/logs
cd $FXA_HOME/bin
#
( ./CommsRouter GRID_ROUTER >& $routerLog ) &
sleep 2
( ./DataController GRID_ROUTER GribController.config >& $decodersLog ) &
sleep 2
( ./DataController GRID_ROUTER GribImgController.config >& $imgDecLog ) &
sleep 2
#
./sendPing GRID_ROUTER 'YYYKWB'
./sendPing GRID_ROUTER 'MMAKWBC'
#

